==> haskell-checkers-0.4.14-3-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.14
id: checkers-0.4.14-Jrnrg8YYR4vLqISij8DvcI
key: checkers-0.4.14-Jrnrg8YYR4vLqISij8DvcI
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: e9f387d462ca4c7d5b0138be6fc83927
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.4/site-local/checkers-0.4.14
library-dirs: /usr/lib/ghc-8.6.4/site-local/checkers-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/checkers-0.4.14
hs-libraries: HScheckers-0.4.14-Jrnrg8YYR4vLqISij8DvcI
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 array-0.5.3.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.2-Bu2F7FQ92OC5GMxlQHm35r
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-checkers-0.4.14-4-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-checkers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: checkers
version: 0.4.14
id: checkers-0.4.14-L0nrUsiRiYA4LSMtzchu4w
key: checkers-0.4.14-L0nrUsiRiYA4LSMtzchu4w
license: BSD-3-Clause
copyright: (c) 2008-2013 by Conal Elliott
maintainer: conal@conal.net
author: Conal Elliott
stability: experimental
homepage: https://github.com/conal/checkers
synopsis: Check properties on standard classes and data structures.
description:
    '\'''\''Checkers'\'''\'' wraps up the expected properties associated with various
    standard type classes as QuickCheck properties.  Also some morphism
    properties.  It also provides arbitrary instances and generator combinators
    for common data types.
    .
    &#169; 2008-2013 by Conal Elliott; BSD3 license.
category: Testing
abi: a37ebf5695b881f6d21a245b0918585d
exposed: True
exposed-modules:
    Test.QuickCheck.Bottoms Test.QuickCheck.Checkers
    Test.QuickCheck.Classes Test.QuickCheck.Instances
    Test.QuickCheck.Instances.Array Test.QuickCheck.Instances.Char
    Test.QuickCheck.Instances.Eq Test.QuickCheck.Instances.List
    Test.QuickCheck.Instances.Maybe Test.QuickCheck.Instances.Num
    Test.QuickCheck.Instances.Ord Test.QuickCheck.Instances.Tuple
    Test.QuickCheck.Later Test.QuickCheck.Utils
hidden-modules: Control.Monad.Extensions
import-dirs: /usr/lib/ghc-8.6.4/site-local/checkers-0.4.14
library-dirs: /usr/lib/ghc-8.6.4/site-local/checkers-0.4.14
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.4/checkers-0.4.14
hs-libraries: HScheckers-0.4.14-L0nrUsiRiYA4LSMtzchu4w
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 array-0.5.3.0
    base-4.12.0.0 random-1.1-3ypV4EIycgb35PKjTYYr5q
    semigroupoids-5.3.2-6cGZnsTtyvVHGOOC0iaPbd
haddock-interfaces: /usr/share/doc/haskell-checkers/html/checkers.haddock
haddock-html: /usr/share/doc/haskell-checkers/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
